dicomparser module
---------------------------------

.. automodule:: dicompylercore.dicomparser
    :members:
    :undoc-members:
    :show-inheritance:

dvh module
-------------------------

.. automodule:: dicompylercore.dvh
    :members:
    :undoc-members:
    :show-inheritance:

dvhcalc module
-----------------------------

.. automodule:: dicompylercore.dvhcalc
    :members:
    :undoc-members:
    :show-inheritance:
